@@ -114,5 +114,52 @@ def test_say_silent():
     r1 = say("this is output")
     r2 = say("this is output", silent=True)
     assert r1 == r2
+    
+def test_indent():
+    setup()
+    assert say('no indent') == 'no indent'
+    assert say('no indent', indent=0) == 'no indent'
+    assert say('one indent', indent='1')  == '    one indent'
+    assert say('one indent', indent='+1') == '    one indent'
+    assert say('two indent', indent=2) == '        two indent'
+    say.set(indent=1)
+    assert say('auto one indent') == '    auto one indent'
+    assert say('one plus one indent', indent='+1') == '        one plus one indent'
+    assert say('subtract indent', indent='-1') == 'subtract indent'
+    assert say('force no indent', indent=0) == 'force no indent'
+    say.set(indent=0)
+    assert say('no indent again') == 'no indent again'
+
+
+def test_indent_special():
+    setup()
+    say.set(indent_str='>>> ')
+    assert say('something') == 'something'
+    assert say('else', indent=1) == '>>> else'
+    assert say('again', indent=2) == '>>> >>> again'
+    say.set(indent_str='| ')
+    assert say("some text") == 'some text'
+    assert say("other", indent="+1") == '| other'
+    
+def test_indent_multiline():
+    setup()
+    assert say('and off\nwe go', indent='+1') == '    and off\n    we go'
+    
+def test_with_indent():
+    setup()
+    with say.settings(indent='+1'):
+        assert say("I am indented!") == "    I am indented!"
+        with say.settings(indent='+1'):
+            assert say("xyz") == "        xyz"
+        assert say('one back') == '    one back'
+    assert say('back again') == 'back again'
+    
+def test_example_3():
+    setup()
+    items = '1 2 3'.split()
+    
+    assert say('TITLE') == 'TITLE'
+    for item in items:
+        assert say(item, indent=1) == '    ' + str(item)
   
 globalvar = 99
